@@ -22,8 +22,11 @@ import java.text.ParseException;
 public class PriceUtil {
     
     public static BigDecimal convertToBigDecimal(String price) throws ParseException {
+        
+        String subPrice = price.substring(price.indexOf('+')+1);
+        
         NumberFormat nf = NumberFormat.getInstance();
-        return new BigDecimal(nf.parse(price).toString());
+        return new BigDecimal(nf.parse(subPrice).toString());
     }
     
 }
